@@ -25,7 +25,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 	match_date_and_time
 );
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 # XXX TODO: find a way to make standard formats available.
 # For example, having a format that you know Postgres will accept as a valid
@@ -41,6 +41,7 @@ sub match_date_and_time {
 
 	my $format = _prepare_date_format($fmt);
 	my ($date,$Y,$M,$D,$h,$m,$s) = _parse_date_format($format,$self->get_current_constraint_value);
+	return if not defined $date;
 
 	
 	# We need to check the date if we find any in the format string, otherwise, it succeeds
@@ -66,11 +67,15 @@ sub _prepare_date_format {
 
     my ($i, @order) = 0;
     $format =~ s{([YMDhms]+|pp)(\?)?}{
-        $order[$i++] = substr($1,0,1);
-        if ($1 eq 'pp') {
+        my ($chr,$q) = ($1,$2);
+        $chr = '' if not defined $chr;
+        $q   = '' if not defined $chr;
+
+        $order[$i++] = substr($chr,0,1);
+        if ($chr eq 'pp') {
             "(AM|PM|am|pm)"
         } else {
-            '('.('\d' x length($1))."$2)"
+            '(' . ('\d' x length($chr)) . ($q ? $q : "") . ")"
         }
     }ge;
 
@@ -90,16 +95,19 @@ sub _parse_date_format {
         $result{$format->[1]->[$i]} ||= $data[$i];
     }
 
-    $result{h} += 12 if ($result{p} eq 'PM' and $result{h} != 12);
-    $result{h} = 0   if ($result{p} eq 'AM' and $result{h} == 12);
+    if (exists $result{p}) {
+        $result{h} += 12 if ($result{p} eq 'PM' and $result{h} != 12);
+        $result{h} = 0   if ($result{p} eq 'AM' and $result{h} == 12);
+    }
 
 
-    return $untainted_date, map $result{$_}, qw(Y M D h m s);
+    return $untainted_date, map {defined $result{$_} ? $result{$_} : 0} qw(Y M D h m s);
+    #return $untainted_date, map $result{$_}, qw(Y M D h m s);
+    #return $untainted_date, map {defined $result{$_} ? $result{$_} : ''} qw(Y M D h m s);
 }
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
